@@ -1,10 +1,12 @@
 "dataquality"
 
-__version__ = "v0.3.0"
+__version__ = "v0.3.1"
 
+import os
 import resource
 
 import dataquality.core._config
+import dataquality.metrics
 from dataquality.core._config import config
 from dataquality.core.auth import login
 from dataquality.core.finish import finish, get_run_status, wait_for_run
@@ -24,8 +26,10 @@ from dataquality.core.log import (
     set_tasks_for_run,
 )
 from dataquality.utils.dq_logger import get_dq_log_file
+from dataquality.utils.helpers import check_noop
 
 
+@check_noop
 def configure() -> None:
     """Update your active config with new env variables.
     Reset user token on configure and prompt new login.
@@ -33,6 +37,8 @@ def configure() -> None:
     Available environment variables to update:
     * GALILEO_CONSOLE_URL
     """
+    if "GALILEO_API_URL" in os.environ:
+        del os.environ["GALILEO_API_URL"]
     updated_config = dataquality.core._config.reset_config()
     for k, v in updated_config.dict().items():
         config.__setattr__(k, v)
