@@ -190,6 +190,7 @@ class TextClassificationDataLogger(BaseGalileoDataLogger):
         self,
         dataset: DataSet,
         *,
+        batch_size: int = ITER_CHUNK_SIZE,
         text: Union[str, int] = "text",
         id: Union[str, int] = "id",
         label: Optional[Union[str, int]] = "label",
@@ -204,6 +205,7 @@ class TextClassificationDataLogger(BaseGalileoDataLogger):
         :param dataset: The dataset to log. This can be an python iterable or
             Pandas/Vaex dataframe. If an iterable, it can be a list of elements that can
             be indexed into either via int index (tuple/list) or string/key index (dict)
+        :param batch_size: Number of samples to log in a batch. Default 100,000
         :param text: The key/index of the text fields
         :param id: The key/index of the id fields
         :param label: The key/index of the label fields
@@ -227,21 +229,52 @@ class TextClassificationDataLogger(BaseGalileoDataLogger):
             dataset = dataset.rename(columns=column_map)
             self._log_df(dataset, meta)
         elif isinstance(dataset, DataFrame):
-            for chunk in range(0, len(dataset), ITER_CHUNK_SIZE):
-                chunk_df = dataset[chunk : chunk + ITER_CHUNK_SIZE]
+            for chunk in range(0, len(dataset), batch_size):
+                chunk_df = dataset[chunk : chunk + batch_size]
                 chunk_df = rename_df(chunk_df, column_map)
                 self._log_df(chunk_df, meta)
+        elif self.is_hf_dataset(dataset):
+            self._log_hf_dataset(
+                dataset, batch_size, text, id, meta, label, split, inference_name
+            )
         elif isinstance(dataset, Iterable):
-            self._log_iterator(dataset, text, id, meta, label, split, inference_name)
+            self._log_iterator(
+                dataset, batch_size, text, id, meta, label, split, inference_name
+            )
         else:
             raise GalileoException(
                 f"Dataset must be one of pandas, vaex, or Iterable, "
                 f"but got {type(dataset)}"
             )
 
+    def _log_hf_dataset(
+        self,
+        dataset: Any,
+        batch_size: int,
+        text: Union[str, int],
+        id: Union[str, int],
+        meta: List[Union[str, int]],
+        label: Union[str, int] = None,
+        split: Split = None,
+        inference_name: str = None,
+    ) -> None:
+        """Helper function to log a huggingface dataset
+
+        HuggingFace datasets can be sliced, returning a dict that is in the correct
+        format to log directly.
+        """
+        for i in range(0, len(dataset), batch_size):
+            chunk = dataset[i : i + batch_size]
+            data = dict(
+                text=chunk[text], id=chunk[id], label=chunk[label] if label else None
+            )
+            chunk_meta = {col: chunk[col] for col in meta}
+            self._log_dict(data, chunk_meta, split, inference_name)
+
     def _log_iterator(
         self,
         dataset: Iterable,
+        batch_size: int,
         text: Union[str, int],
         id: Union[str, int],
         meta: List[Union[str, int]],
@@ -261,7 +294,7 @@ class TextClassificationDataLogger(BaseGalileoDataLogger):
             for meta_col in meta:
                 metas[meta_col].append(self._convert_tensor_to_py(chunk[meta_col]))
 
-            if len(batches["text"]) >= ITER_CHUNK_SIZE:
+            if len(batches["text"]) >= batch_size:
                 self._log_dict(batches, metas, split, inference_name)
                 batches.clear()
                 metas.clear()
@@ -347,8 +380,21 @@ class TextClassificationDataLogger(BaseGalileoDataLogger):
             f"(ids, text) ({id_len}, {text_len})"
         )
 
+        self.validate_logged_labels()
         self.validate_metadata(batch_size=text_len)
 
+    def validate_logged_labels(self) -> None:
+        """Validates that the labels logged match the labels set"""
+        self.logger_config.observed_labels.update(self.labels)
+        found_labels = self.logger_config.observed_labels
+        if self.logger_config.labels:
+            set_labels = set(self.logger_config.labels)
+            assert set_labels.issuperset(found_labels), (
+                f"Labels set to {set_labels} but found logged labels {found_labels}. "
+                f"Logged labels must be the same as labels set during "
+                f"dq.set_labels_for_run. Fix logged data or update labels."
+            )
+
     def _get_input_df(self) -> DataFrame:
         inp = dict(
             id=self.ids,
@@ -406,3 +452,10 @@ class TextClassificationDataLogger(BaseGalileoDataLogger):
             f"model is expecting {cls.logger_config.observed_num_labels} labels. "
             f"Use dataquality.set_labels_for_run to update your config labels."
         )
+
+        assert cls.logger_config.observed_labels.issubset(cls.logger_config.labels), (
+            f"Labels set to {cls.logger_config.labels} do not align with observed "
+            f"logged labels of {cls.logger_config.observed_labels}. Set labels must "
+            "contain all logged labels. Update your labels with "
+            "`dq.set_labels_for_run` or fix input data."
+        )
