@@ -275,3 +275,34 @@ def test_log_model_outputs_binary_bad_shapes(
             f"In binary multi-label, your logits should have 2 dimensions, but they "
             f"currently have {len(dims)}."
         ) in err
+
+
+@pytest.mark.parametrize("set_labels_first", [True, False])
+def test_logged_labels_dont_match_set_labels(
+    set_labels_first: bool, set_test_config: Callable, cleanup_after_use: Callable
+) -> None:
+    """An error should be thrown when the set labels dont match the logged labels"""
+    set_test_config(task_type="text_multi_label")
+    labels = [["A", "NOT_A"], ["B", "NOT_B"], ["C", "NOT_C"]]
+    # labels are the index, not the actual labels. No good
+    dataset = pd.DataFrame(
+        {
+            "text": ["sample1", "sample2", "sample3"],
+            "label": [[1, 1, 2], [3, 1, 2], [2, 3, 2]],
+            "id": [1, 2, 3],
+        }
+    )
+    if set_labels_first:
+        dataquality.set_labels_for_run(labels)
+        with pytest.raises(AssertionError) as e:
+            dataquality.log_dataset(dataset, split="train")
+        assert str(e.value).startswith(
+            "The input labels you log must be exactly the same"
+        )
+    else:
+        dataquality.log_dataset(dataset, split="train")
+        dataquality.get_data_logger().logger_config.observed_num_labels = [2, 2, 2]
+        dataquality.set_labels_for_run(labels)
+        with pytest.raises(AssertionError) as e:
+            dataquality.get_data_logger().validate_labels()
+        assert str(e.value).startswith("The labels set for task #")
